summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--.gitignore2
-rw-r--r--Changelog1
-rw-r--r--Makefile8
-rw-r--r--avplay.c (renamed from ffplay.c)12
-rwxr-xr-xconfigure10
-rw-r--r--doc/avplay.texi (renamed from doc/ffplay.texi)12
-rw-r--r--doc/demuxers.texi2
-rw-r--r--doc/developer.texi2
-rw-r--r--doc/ffmpeg.texi2
-rw-r--r--doc/ffprobe.texi2
-rw-r--r--doc/ffserver.texi2
-rw-r--r--doc/general.texi2
-rw-r--r--doc/indevs.texi4
-rw-r--r--doc/libavfilter.texi4
-rw-r--r--doc/protocols.texi28
15 files changed, 47 insertions, 46 deletions
diff --git a/.gitignore b/.gitignore
index bfce23d311..e867470820 100644
--- a/.gitignore
+++ b/.gitignore
@@ -12,7 +12,7 @@ doc/*.html
doc/*.pod
doxy
ffmpeg
-ffplay
+avplay
ffprobe
ffserver
libavcodec/*_tablegen
diff --git a/Changelog b/Changelog
index 7b8be5b302..ad3d867cb4 100644
--- a/Changelog
+++ b/Changelog
@@ -5,6 +5,7 @@ releases are sorted from youngest to oldest.
version <next>:
- BWF muxer
- Flash Screen Video 2 decoder
+- ffplay renamed to avplay
version 0.7:
diff --git a/Makefile b/Makefile
index 9d6ec3a46d..5214f5a45e 100644
--- a/Makefile
+++ b/Makefile
@@ -53,7 +53,7 @@ COMPILE_S = $(call COMPILE,AS)
%.c %.h: TAG = GEN
PROGS-$(CONFIG_FFMPEG) += ffmpeg
-PROGS-$(CONFIG_FFPLAY) += ffplay
+PROGS-$(CONFIG_AVPLAY) += avplay
PROGS-$(CONFIG_FFPROBE) += ffprobe
PROGS-$(CONFIG_FFSERVER) += ffserver
@@ -64,7 +64,7 @@ HOSTPROGS := $(TESTTOOLS:%=tests/%)
TOOLS = qt-faststart trasher
TOOLS-$(CONFIG_ZLIB) += cws2fws
-BASENAMES = ffmpeg ffplay ffprobe ffserver
+BASENAMES = ffmpeg avplay ffprobe ffserver
ALLPROGS = $(BASENAMES:%=%$(EXESUF))
ALLMANPAGES = $(BASENAMES:%=%.1)
@@ -116,8 +116,8 @@ endef
$(foreach D,$(FFLIBS),$(eval $(call DOSUBDIR,lib$(D))))
-ffplay.o: CFLAGS += $(SDL_CFLAGS)
-ffplay$(EXESUF): FF_EXTRALIBS += $(SDL_LIBS)
+avplay.o: CFLAGS += $(SDL_CFLAGS)
+avplay$(EXESUF): FF_EXTRALIBS += $(SDL_LIBS)
ffserver$(EXESUF): LDFLAGS += $(FFSERVERLDFLAGS)
$(PROGS): %$(EXESUF): %.o cmdutils.o $(FF_DEP_LIBS)
diff --git a/configure b/configure
index ef2c566d85..7277409996 100755
--- a/configure
+++ b/configure
@@ -81,7 +81,7 @@ Configuration options:
and binaries will be unredistributable [no]
--disable-doc do not build documentation
--disable-ffmpeg disable ffmpeg build
- --disable-ffplay disable ffplay build
+ --disable-avplay disable avplay build
--disable-ffprobe disable ffprobe build
--disable-ffserver disable ffserver build
--disable-avdevice disable libavdevice build
@@ -913,7 +913,7 @@ CONFIG_LIST="
dxva2
fastdiv
ffmpeg
- ffplay
+ avplay
ffprobe
ffserver
fft
@@ -1489,8 +1489,8 @@ postproc_deps="gpl"
# programs
ffmpeg_deps="avcodec avformat swscale"
ffmpeg_select="buffer_filter"
-ffplay_deps="avcodec avformat swscale sdl"
-ffplay_select="rdft"
+avplay_deps="avcodec avformat swscale sdl"
+avplay_select="rdft"
ffprobe_deps="avcodec avformat"
ffserver_deps="avformat ffm_muxer fork rtp_protocol rtsp_demuxer"
ffserver_extralibs='$ldl'
@@ -1635,7 +1635,7 @@ enable debug
enable doc
enable fastdiv
enable ffmpeg
-enable ffplay
+enable avplay
enable ffprobe
enable ffserver
enable network
diff --git a/doc/ffplay.texi b/doc/avplay.texi
index d60852603a..0c74c59a3d 100644
--- a/doc/ffplay.texi
+++ b/doc/avplay.texi
@@ -1,8 +1,8 @@
\input texinfo @c -*- texinfo -*-
-@settitle ffplay Documentation
+@settitle avplay Documentation
@titlepage
-@center @titlefont{ffplay Documentation}
+@center @titlefont{avplay Documentation}
@end titlepage
@top
@@ -13,14 +13,14 @@
@example
@c man begin SYNOPSIS
-ffplay [options] @file{input_file}
+avplay [options] @file{input_file}
@c man end
@end example
@chapter Description
@c man begin DESCRIPTION
-FFplay is a very simple and portable media player using the Libav
+AVplay is a very simple and portable media player using the Libav
libraries and the SDL library. It is mostly used as a testbed for the
various Libav APIs.
@c man end
@@ -166,8 +166,8 @@ Seek to percentage in file corresponding to fraction of width.
@ignore
-@setfilename ffplay
-@settitle FFplay media player
+@setfilename avplay
+@settitle AVplay media player
@c man begin SEEALSO
ffmpeg(1), ffprobe(1), ffserver(1) and the Libav HTML documentation
diff --git a/doc/demuxers.texi b/doc/demuxers.texi
index 98f9fdeff8..fc03459417 100644
--- a/doc/demuxers.texi
+++ b/doc/demuxers.texi
@@ -70,7 +70,7 @@ Apple HTTP Live Streaming demuxer.
This demuxer presents all AVStreams from all variant streams.
The id field is set to the bitrate variant index number. By setting
-the discard flags on AVStreams (by pressing 'a' or 'v' in ffplay),
+the discard flags on AVStreams (by pressing 'a' or 'v' in avplay),
the caller can decide which variant streams to actually receive.
The total bitrate of the variant that the stream belongs to is
available in a metadata key named "variant_bitrate".
diff --git a/doc/developer.texi b/doc/developer.texi
index 208c119753..d75471cb29 100644
--- a/doc/developer.texi
+++ b/doc/developer.texi
@@ -17,7 +17,7 @@
decoding). Look at @file{libavcodec/apiexample.c} to see how to use it.
@item libavformat is the library containing the file format handling (mux and
-demux code for several formats). Look at @file{ffplay.c} to use it in a
+demux code for several formats). Look at @file{avplay.c} to use it in a
player. See @file{libavformat/output-example.c} to use it to generate
audio or video streams.
diff --git a/doc/ffmpeg.texi b/doc/ffmpeg.texi
index ca801d31e4..6393516c6d 100644
--- a/doc/ffmpeg.texi
+++ b/doc/ffmpeg.texi
@@ -1079,7 +1079,7 @@ file to which you want to add them.
@settitle ffmpeg video converter
@c man begin SEEALSO
-ffplay(1), ffprobe(1), ffserver(1) and the Libav HTML documentation
+avplay(1), ffprobe(1), ffserver(1) and the Libav HTML documentation
@c man end
@c man begin AUTHORS
diff --git a/doc/ffprobe.texi b/doc/ffprobe.texi
index 5e856e6645..079cf659d7 100644
--- a/doc/ffprobe.texi
+++ b/doc/ffprobe.texi
@@ -122,7 +122,7 @@ with name "STREAM".
@settitle ffprobe media prober
@c man begin SEEALSO
-ffmpeg(1), ffplay(1), ffserver(1) and the Libav HTML documentation
+ffmpeg(1), avplay(1), ffserver(1) and the Libav HTML documentation
@c man end
@c man begin AUTHORS
diff --git a/doc/ffserver.texi b/doc/ffserver.texi
index d247016bbc..3d64b79377 100644
--- a/doc/ffserver.texi
+++ b/doc/ffserver.texi
@@ -265,7 +265,7 @@ rather than as a daemon.
@c man begin SEEALSO
-ffmpeg(1), ffplay(1), ffprobe(1), the @file{ffmpeg/doc/ffserver.conf}
+ffmpeg(1), avplay(1), ffprobe(1), the @file{ffmpeg/doc/ffserver.conf}
example and the Libav HTML documentation
@c man end
diff --git a/doc/general.texi b/doc/general.texi
index c9919390d6..98065093b5 100644
--- a/doc/general.texi
+++ b/doc/general.texi
@@ -837,7 +837,7 @@ speed up is close to non-existent for normal one-off builds and is only
noticeable when running make for a second time (for example in
@code{make install}).
-@item In order to compile FFplay, you must have the MinGW development library
+@item In order to compile AVplay, you must have the MinGW development library
of @uref{http://www.libsdl.org/, SDL}.
Edit the @file{bin/sdl-config} script so that it points to the correct prefix
where SDL was installed. Verify that @file{sdl-config} can be launched from
diff --git a/doc/indevs.texi b/doc/indevs.texi
index fa21c099d5..e1c058b8a6 100644
--- a/doc/indevs.texi
+++ b/doc/indevs.texi
@@ -199,10 +199,10 @@ tools.
@example
# Grab and show the input of a video4linux device, frame rate is set
# to the default of 25/1.
-ffplay -s 320x240 -f video4linux /dev/video0
+avplay -s 320x240 -f video4linux /dev/video0
# Grab and show the input of a video4linux2 device, autoadjust size.
-ffplay -f video4linux2 /dev/video0
+avplay -f video4linux2 /dev/video0
# Grab and record the input of a video4linux2 device, autoadjust size,
# frame rate value defaults to 0/0 so it is read from the video4linux2
diff --git a/doc/libavfilter.texi b/doc/libavfilter.texi
index 1c1220541c..172b7fc4d0 100644
--- a/doc/libavfilter.texi
+++ b/doc/libavfilter.texi
@@ -24,7 +24,7 @@ some directory of your choice by:
@end example
And then read the README file in the top directory to learn how to
-integrate it into ffmpeg and ffplay.
+integrate it into ffmpeg and avplay.
But note that there may still be serious bugs in the code and its API
and ABI should not be considered stable yet!
@@ -56,7 +56,7 @@ result will be that in output the top half of the video is mirrored
onto the bottom half.
Video filters are loaded using the @var{-vf} option passed to
-ffmpeg or to ffplay. Filters in the same linear chain are separated by
+ffmpeg or to avplay. Filters in the same linear chain are separated by
commas. In our example, @var{split, fifo, overlay} are in one linear
chain, and @var{fifo, crop, vflip} are in another. The points where
the linear chains join are labeled by names enclosed in square
diff --git a/doc/protocols.texi b/doc/protocols.texi
index 59906312fa..cc35982e77 100644
--- a/doc/protocols.texi
+++ b/doc/protocols.texi
@@ -52,10 +52,10 @@ resource to be concatenated, each one possibly specifying a distinct
protocol.
For example to read a sequence of files @file{split1.mpeg},
-@file{split2.mpeg}, @file{split3.mpeg} with @file{ffplay} use the
+@file{split2.mpeg}, @file{split3.mpeg} with @file{avplay} use the
command:
@example
-ffplay concat:split1.mpeg\|split2.mpeg\|split3.mpeg
+avplay concat:split1.mpeg\|split2.mpeg\|split3.mpeg
@end example
Note that you may need to escape the character "|" which is special for
@@ -183,10 +183,10 @@ application specified in @var{app}, may be prefixed by "mp4:".
@end table
-For example to read with @file{ffplay} a multimedia resource named
+For example to read with @file{avplay} a multimedia resource named
"sample" from the application "vod" from an RTMP server "myserver":
@example
-ffplay rtmp://myserver/vod/sample
+avplay rtmp://myserver/vod/sample
@end example
@section rtmp, rtmpe, rtmps, rtmpt, rtmpte
@@ -224,9 +224,9 @@ For example, to stream a file in real-time to an RTMP server using
ffmpeg -re -i myfile -f flv rtmp://myserver/live/mystream
@end example
-To play the same stream using @file{ffplay}:
+To play the same stream using @file{avplay}:
@example
-ffplay "rtmp://myserver/live/mystream live=1"
+avplay "rtmp://myserver/live/mystream live=1"
@end example
@section rtp
@@ -281,7 +281,7 @@ When receiving data over UDP, the demuxer tries to reorder received packets
order for this to be enabled, a maximum delay must be specified in the
@code{max_delay} field of AVFormatContext.
-When watching multi-bitrate Real-RTSP streams with @file{ffplay}, the
+When watching multi-bitrate Real-RTSP streams with @file{avplay}, the
streams to display can be chosen with @code{-vst} @var{n} and
@code{-ast} @var{n} for video and audio respectively, and can be switched
on the fly by pressing @code{v} and @code{a}.
@@ -291,13 +291,13 @@ Example command lines:
To watch a stream over UDP, with a max reordering delay of 0.5 seconds:
@example
-ffplay -max_delay 500000 rtsp://server/video.mp4?udp
+avplay -max_delay 500000 rtsp://server/video.mp4?udp
@end example
To watch a stream tunneled over HTTP:
@example
-ffplay rtsp://server/video.mp4?http
+avplay rtsp://server/video.mp4?http
@end example
To send a stream in realtime to a RTSP server, for others to watch:
@@ -358,13 +358,13 @@ To broadcast a stream on the local subnet, for watching in VLC:
ffmpeg -re -i @var{input} -f sap sap://224.0.0.255?same_port=1
@end example
-Similarly, for watching in ffplay:
+Similarly, for watching in avplay:
@example
ffmpeg -re -i @var{input} -f sap sap://224.0.0.255
@end example
-And for watching in ffplay, over IPv6:
+And for watching in avplay, over IPv6:
@example
ffmpeg -re -i @var{input} -f sap sap://[ff0e::1:2:3:4]
@@ -389,13 +389,13 @@ Example command lines follow.
To play back the first stream announced on the normal SAP multicast address:
@example
-ffplay sap://
+avplay sap://
@end example
To play back the first stream announced on one the default IPv6 SAP multicast address:
@example
-ffplay sap://[ff0e::2:7ffe]
+avplay sap://[ff0e::2:7ffe]
@end example
@section tcp
@@ -414,7 +414,7 @@ Listen for an incoming connection
@example
ffmpeg -i @var{input} -f @var{format} tcp://@var{hostname}:@var{port}?listen
-ffplay tcp://@var{hostname}:@var{port}
+avplay tcp://@var{hostname}:@var{port}
@end example
@end table
diff --git a/ffplay.c b/avplay.c
index bef75fe574..f43cf6faa6 100644
--- a/ffplay.c
+++ b/avplay.c
@@ -1,5 +1,5 @@
/*
* ffplay : Simple Media Player based on the Libav libraries
* Copyright (c) 2003 Fabrice Bellard
*
* This file is part of Libav.
@@ -55,7 +55,7 @@
#include <unistd.h>
#include <assert.h>
-const char program_name[] = "ffplay";
+const char program_name[] = "avplay";
const int program_birth_year = 2003;
#define MAX_QUEUE_SIZE (15 * 1024 * 1024)
@@ -1678,7 +1678,7 @@ static int input_config_props(AVFilterLink *link)
static AVFilter input_filter =
{
- .name = "ffplay_input",
+ .name = "avplay_input",
.priv_size = sizeof(FilterPriv),
@@ -2357,7 +2357,7 @@ static int decode_thread(void *arg)
av_freep(&opts);
if(ic->pb)
- ic->pb->eof_reached= 0; //FIXME hack, ffplay maybe should not use url_feof() to test for the end
+ ic->pb->eof_reached= 0; //FIXME hack, avplay maybe should not use url_feof() to test for the end
if(seek_by_bytes<0)
seek_by_bytes= !!(ic->iformat->flags & AVFMT_TS_DISCONT);
@@ -2954,7 +2954,7 @@ static const OptionDef options[] = {
static void show_usage(void)
{
printf("Simple media player\n");
- printf("usage: ffplay [options] input_file\n");
+ printf("usage: %s [options] input_file\n", program_name);
printf("\n");
}
@@ -3030,7 +3030,7 @@ int main(int argc, char **argv)
if (!input_filename) {
show_usage();
fprintf(stderr, "An input file must be specified\n");
- fprintf(stderr, "Use -h to get full help or, even better, run 'man ffplay'\n");
+ fprintf(stderr, "Use -h to get full help or, even better, run 'man %s'\n", program_name);
exit(1);
}
@@ -1,5 +1,5 @@
/*
- * ffplay : Simple Media Player based on the Libav libraries
+ * avplay : Simple Media Player based on the Libav libraries
* Copyright (c) 2003 Fabrice Bellard
*